# Load required libraries
library(ape); library (ggplot2);library(lme4); library(e1071); library(ggpubr)                
library(caper) # Vresion 0.5.2
library(nlme) # Version 3.1.122
library(lavaan); library(plm);library(plyr);library(lme4);library(lmerTest);library(car);library(nlme);library(lattice)
# Load piecewiseSEM from CRAN
# install.packages("piecewiseSEM")
library(piecewiseSEM) # Version 1.0.0

range.std<-function(x){(x-min(x, na.rm = T))/(max(x, na.rm = T)-min(x, na.rm = T))}

soda = read.csv("Annex 3.csv",sep=";",dec=".")
soda<-soda[1:136,]
soda$dummy<-rep(1,nrow(soda))
soda2 = na.omit(soda)
soda3 = soda[which(is.na(soda$VLP)==F),]
str(soda)

#Steps:
# 0. Establish a path diagram based on your knowledge of the system
# 1. Look for non-linearities that need to be accounted for and determine when random lake effects should be included
# 2. Establish different model sub-sets and identify optimal models based on AIC; note down if the inclusion of a dependent 
#    variable only marginally improves the AIC
# 3. Define and run the SEM-model - does the model converge? If not, make necessary adjustments 
#    Run SEM diagnostics; make necessary adjustments if necessary
#    Extract r2 and path coefficients

###### Step 1 - identify relationships ########
library(lme4)
# A) DOC, DM should not be logged - but it does not make a big difference...
DM<-lmer(DOC ~ Salinity + (1|Lake)+ (0+Salinity|Lake) ,data = soda2, na.action = na.omit)
DM1<-lm(DOC ~ (Salinity) + Lake + Lake:(Salinity) ,data = soda2, na.action = na.omit)
DM2<-lm(DOC ~ Salinity + Lake + Lake:Salinity + DM ,data = soda2, na.action = na.omit) 
DM3<-lm(DOC ~ Salinity + Lake + Lake:Salinity + log(DM)  ,data = soda2, na.action = na.omit)
DM4<-lm(DOC ~ Salinity + Lake + Lake:Salinity + log(DM) + VLP:Lake  ,data = soda2, na.action = na.omit)
DM5<-lm(DOC ~ Salinity + Lake + Lake:Salinity + VLP:Lake  ,data = soda2, na.action = na.omit)

AIC(DM, DM1, DM2, DM3, DM4, DM5)
BIC(DM, DM1, DM2, DM3, DM4)

soda2$residuals<-residuals(DM2)
ggplot(data = soda2, aes(y=residuals, x=log(VLP), colour = Lake))+geom_point()
ggplot(data = soda2, aes(y=DOC, x=Salinity, colour = Lake))+geom_point()

DM.f<-lm(range.std(DOC) ~ Lake + Lake:range.std(Salinity) + range.std(log(DM)) ,data = soda, na.action = na.omit) 
summary(DM.f)

# B) Chla; DM & Grazer_small should be logged, 
Chla = lm(Chla~ VLP + Grazer_large + DM, data = soda, na.action = na.omit)
Chla = lm(Chla~ log(DM), data = soda2, na.action = na.omit)
Chla1 = lm(Chla~ log(DM)+(Grazer_large), data = soda2, na.action = na.omit)
Chla2 = lm(Chla~ log(DM)+(Grazer_large)+VLP, data = soda2, na.action = na.omit)
Chla3 = lm(Chla~ log(DM)+(Grazer_large)+VLP+VLP:Lake, data = soda2, na.action = na.omit)
Chla4 = lm(Chla~ log(DM)+(Grazer_large)+VLP+VLP:Lake+log(Grazer_small), data = soda2, na.action = na.omit)
Chla5 = lm(Chla~ log(DM)+VLP+VLP:Lake+log(Grazer_small), data = soda2, na.action = na.omit)

AIC(Chla, Chla1,Chla2,Chla3,Chla4,Chla5)
BIC(Chla, Chla1,Chla2,Chla3,Chla4,Chla5)

soda2$residuals<-residuals(Chla5)
ggplot(data = soda2, aes(y=(residuals), x=log(Grazer_large), colour = Lake))+geom_point()

Chla.f = lm(range.std(Chla)~ range.std(log(DM))+ range.std(log(VLP)):Lake + range.std(log(Grazer_small)), 
            data = soda2, na.action = na.omit)
summary(Chla.f)


# C) E2_E3, log either DOC or E2_E3 - approximately the same outcome...
E2_E3 = lm(log(E2_E3)~(DOC) + Lake:(DOC) + Lake, data = soda, na.action = na.omit)
E2_E31 = lm(log(E2_E3)~ Lake , data = soda, na.action = na.omit)
E2_E32 = lm(log(E2_E3)~log(DOC) + Lake:(DOC) + Lake, data = soda, na.action = na.omit)

summary(E2_E32)
AIC(E2_E3, E2_E31,E2_E32)

mod.DM<-lm(log(DOC)~(Salinity)+Lake:(Salinity)+Lake,data=soda)
ggplot(soda,aes(x=log(DOC), y=log(E2_E3), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

E2_E3.f = lm(range.std(E2_E3) ~ Lake + range.std(DOC) :  Lake , data = soda, na.action = na.omit)
summary(E2_E3.f)

# D) DM; DM should be logged
DM = lm(log(DM)~(Salinity)+Lake:(Salinity)+Lake,data=soda)
DM1 = lm(log(DM)~(Salinity)+Lake:(Salinity),data=soda)

summary(DM)
AIC(DM, DM1)

DM.f = lm(log(DM)~(Salinity)+Lake:(Salinity)+Lake,data=soda)


# D) HP; DM should NOT be logged
HP = lm((HP)~ DOC+ VLP+(DM),data = soda3, na.action = na.omit)
HP1 = lm((HP)~ DOC+(VLP)+DM+Lake+DOC:Lake,data = soda3, na.action = na.omit)
HP2 = lm((HP)~ DOC+DM,data = soda3, na.action = na.omit)
HP3 = lm((HP)~ DOC+VLP,data = soda3, na.action = na.omit)
HP4 = lm((HP)~ DOC+VLP+DM+Lake+Lake:VLP,data = soda3, na.action = na.omit)
HP5 = lm((HP)~ DOC+VLP+DM+Lake+Lake:DM,data = soda3, na.action = na.omit)
HP6 = lm((HP)~ DOC+VLP+log(DM),data = soda3, na.action = na.omit)

HP = lm((HP)~ DOC+log(VLP)+(DM),data = soda3, na.action = na.omit)
HP1 = lm((HP)~ DOC+(VLP)+DM+Lake+DOC:Lake,data = soda3, na.action = na.omit)
HP2 = lm((HP)~ DOC+DM,data = soda3, na.action = na.omit)
HP3 = lm((HP)~ DOC+VLP,data = soda3, na.action = na.omit)
HP4 = lm((HP)~ DOC+VLP+DM+Lake+Lake:VLP,data = soda3, na.action = na.omit)
HP5 = lm((HP)~ DOC+VLP+DM+Lake+Lake:DM,data = soda3, na.action = na.omit)
HP6 = lm((HP)~ DOC+VLP+log(DM),data = soda3, na.action = na.omit)

summary(HP)
AIC(HP,HP1,HP2,HP3,HP4,HP5,HP6)
BIC(HP,HP1,HP2,HP3,HP4,HP5,HP6)

soda3$residuals<-residuals(HP)
ggplot(soda3,aes(x=Grazer_small, y=log(HP), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

HP.f = lm(range.std(log(HP))~ range.std(DOC)+range.std(log(VLP))+range.std(DM),data = soda3, na.action = na.omit)
summary(HP.f)

# E) VLP; DM should not be logged
VLP = lm(log(VLP)~ (DM),data = soda3, na.action = na.omit)
VLP1 = lm(log(VLP)~ DM+Lake+DM:Lake,data = soda3, na.action = na.omit)
VLP2 = lm(log(VLP)~ Lake:DM,data = soda3, na.action = na.omit)
VLP3 = lm(log(VLP)~ Lake,data = soda3, na.action = na.omit)
VLP4 = lm(log(VLP)~ log(DM)*Lake,data = soda3, na.action = na.omit)

summary(VLP1)

AIC(VLP,VLP1,VLP2,VLP3,VLP4)

soda3$residuals<-residuals(HP)
ggplot(soda,aes(x=log(DM), y=log(VLP), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

### Problem - logging and non-logging would be mixed, but that would only affect DM. There are two options - just go forward with a global model, 
# but that leads to a slightly reduced fit or just stay with the sub-model, which is in this case not an issue as there is no danger of confunding 
# interaction effects, the way the model turned out...

# For the global model, the following transformations were hence chosen:

##################################################################################################################
# Step 1 - identify relationships
library(lme4)
# A) DOC, DM should not be logged - but it does not make a big difference...
DM<-lmer(DOC ~ Salinity + (1|Lake)+ (0+Salinity|Lake) ,data = soda2, na.action = na.omit)
DM1<-lm(DOC ~ (Salinity) + Lake + Lake:(Salinity) ,data = soda2, na.action = na.omit)
DM2<-lm(DOC ~ Salinity + Lake + Lake:Salinity + DM ,data = soda2, na.action = na.omit) 
DM3<-lm(DOC ~ Salinity + Lake + Lake:Salinity + log(DM)  ,data = soda2, na.action = na.omit)
DM4<-lm(DOC ~ Salinity + Lake + Lake:Salinity + log(DM) + VLP:Lake  ,data = soda2, na.action = na.omit)
DM5<-lm(DOC ~ Salinity + Lake + Lake:Salinity + VLP:Lake  ,data = soda2, na.action = na.omit)

AIC(DM, DM1, DM2, DM3, DM4, DM5)
BIC(DM, DM1, DM2, DM3, DM4)

soda2$residuals<-residuals(DM2)
ggplot(data = soda2, aes(y=residuals, x=log(VLP), colour = Lake))+geom_point()
ggplot(data = soda2, aes(y=DOC, x=Salinity, colour = Lake))+geom_point()

DM.f<-lm(range.std(DOC) ~ Lake + Lake:range.std(Salinity) + range.std(log(DM)) ,data = soda, na.action = na.omit) 
summary(DM.f)

# B) Chla; DM & Grazer_small should be logged, 
Chla = lm(Chla~ VLP + Grazer_large + DM, data = soda, na.action = na.omit)
Chla = lm(Chla~ log(DM), data = soda2, na.action = na.omit)
Chla1 = lm(Chla~ log(DM)+(Grazer_large), data = soda2, na.action = na.omit)
Chla2 = lm(Chla~ log(DM)+(Grazer_large)+VLP, data = soda2, na.action = na.omit)
Chla3 = lm(Chla~ log(DM)+(Grazer_large)+VLP+VLP:Lake, data = soda2, na.action = na.omit)
Chla4 = lm(Chla~ log(DM)+(Grazer_large)+VLP+VLP:Lake+log(Grazer_small), data = soda2, na.action = na.omit)
Chla5 = lm(Chla~ log(DM)+VLP+VLP:Lake+log(Grazer_small), data = soda2, na.action = na.omit)

AIC(Chla, Chla1,Chla2,Chla3,Chla4,Chla5)
BIC(Chla, Chla1,Chla2,Chla3,Chla4,Chla5)

soda2$residuals<-residuals(Chla5)
ggplot(data = soda2, aes(y=(residuals), x=log(Grazer_large), colour = Lake))+geom_point()

Chla.f = lm(range.std(Chla)~ range.std(log(DM))+ range.std(log(VLP)):Lake + range.std(log(Grazer_small)), 
            data = soda2, na.action = na.omit)
summary(Chla.f)


# C) E2_E3, log either DOC or E2_E3 - approximately the same outcome...
E2_E3 = lm(log(E2_E3)~(DOC) + Lake:(DOC) + Lake, data = soda, na.action = na.omit)
E2_E31 = lm(log(E2_E3)~ Lake , data = soda, na.action = na.omit)
E2_E32 = lm(log(E2_E3)~log(DOC) + Lake:(DOC) + Lake, data = soda, na.action = na.omit)

summary(E2_E32)
AIC(E2_E3, E2_E31,E2_E32)

mod.DM<-lm(log(DOC)~(Salinity)+Lake:(Salinity)+Lake,data=soda)
ggplot(soda,aes(x=log(DOC), y=log(E2_E3), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

E2_E3.f = lm(range.std(E2_E3) ~ Lake + range.std(DOC) :  Lake , data = soda, na.action = na.omit)
summary(E2_E3.f)

# D) DM; DM should be logged
DM = lm(log(DM)~(Salinity)+Lake:(Salinity)+Lake,data=soda)
DM1 = lm(log(DM)~(Salinity)+Lake:(Salinity),data=soda)

summary(DM)
AIC(DM, DM1)

DM.f = lm(log(DM)~(Salinity)+Lake:(Salinity)+Lake,data=soda)


# D) HP; DM should NOT be logged
HP = lm((HP)~ DOC+ VLP+(DM),data = soda3, na.action = na.omit)
HP1 = lm((HP)~ DOC+(VLP)+DM+Lake+DOC:Lake,data = soda3, na.action = na.omit)
HP2 = lm((HP)~ DOC+DM,data = soda3, na.action = na.omit)
HP3 = lm((HP)~ DOC+VLP,data = soda3, na.action = na.omit)
HP4 = lm((HP)~ DOC+VLP+DM+Lake+Lake:VLP,data = soda3, na.action = na.omit)
HP5 = lm((HP)~ DOC+VLP+DM+Lake+Lake:DM,data = soda3, na.action = na.omit)
HP6 = lm((HP)~ DOC+VLP+log(DM),data = soda3, na.action = na.omit)

HP = lm((HP)~ DOC+log(VLP)+(DM),data = soda3, na.action = na.omit)
HP1 = lm((HP)~ DOC+(VLP)+DM+Lake+DOC:Lake,data = soda3, na.action = na.omit)
HP2 = lm((HP)~ DOC+DM,data = soda3, na.action = na.omit)
HP3 = lm((HP)~ DOC+VLP,data = soda3, na.action = na.omit)
HP4 = lm((HP)~ DOC+VLP+DM+Lake+Lake:VLP,data = soda3, na.action = na.omit)
HP5 = lm((HP)~ DOC+VLP+DM+Lake+Lake:DM,data = soda3, na.action = na.omit)
HP6 = lm((HP)~ DOC+VLP+log(DM),data = soda3, na.action = na.omit)

summary(HP)
AIC(HP,HP1,HP2,HP3,HP4,HP5,HP6)
BIC(HP,HP1,HP2,HP3,HP4,HP5,HP6)

soda3$residuals<-residuals(HP)
ggplot(soda3,aes(x=Grazer_small, y=log(HP), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

HP.f = lm(range.std(log(HP))~ range.std(DOC)+range.std(log(VLP))+range.std(DM),data = soda3, na.action = na.omit)
summary(HP.f)

# E) VLP; DM should not be logged
VLP = lm(log(VLP)~ (DM),data = soda3, na.action = na.omit)
VLP1 = lm(log(VLP)~ DM+Lake+DM:Lake,data = soda3, na.action = na.omit)
VLP2 = lm(log(VLP)~ Lake:DM,data = soda3, na.action = na.omit)
VLP3 = lm(log(VLP)~ Lake,data = soda3, na.action = na.omit)
VLP4 = lm(log(VLP)~ log(DM)*Lake,data = soda3, na.action = na.omit)

summary(VLP1)

AIC(VLP,VLP1,VLP2,VLP3,VLP4)

soda3$residuals<-residuals(HP)
ggplot(soda,aes(x=log(DM), y=log(VLP), shape=Lake, color=Lake))+ geom_point(size=2.9,alpha = 0.8)

### Problem - logging and non-logging would be mixed, but that would only affect DM. There are two options - just go forward with a global model, 
# but that leads to a slightly reduced fit or just stay with the sub-model, which is in this case not an issue as there is no danger of confunding 
# interaction effects, the way the model turned out... 

# hence the coefficients from the global and the submodels do not change...
soda4<-soda; soda4$VLP<-log(soda4$VLP); soda4$Grazer_large<-log(soda4$Grazer_large+0.1); soda4$Lake<-as.factor( soda4$Lake)
soda4$Chla<-log(soda4$Chla); soda4$HP<-log(soda4$HP); soda4$DOC<-log(soda4$DOC); soda4$Grazer_small<-log(soda4$Grazer_small+0.1)
soda6<-na.omit(soda4)

#### Step 2 - define the appropriate submodels for the SEM

# AIC model-building approach - 
############################################################################################## VLP
m1 = lme(VLP~ DM, random = ~1| Lake, data = soda4, na.action = na.omit, method ="ML") #BEST!
m2 = lme(VLP~ DM, random = list(Lake = pdDiag(~ DM)), data = soda4, na.action = na.omit, method ="ML")
m3 = lm(VLP~ DM,  data = soda4, na.action = na.omit)

AIC(m1,m2,m3)
summary(m1)
plot(m1)

############################################################################################## HP
m1 = lme(HP~ DOC+VLP+DM, data = soda6, na.action = na.omit, method ="ML", random = ~1| Lake)
m2 = lm(HP~ DOC+VLP+DM +Chla+Grazer_small+E2_E3,data = soda6, na.action = na.omit)
m3 = lm(HP~ DOC+VLP+DM +Grazer_small+E2_E3,data = soda6, na.action = na.omit)
m4 = lm(HP~ DOC+DM +Chla+E2_E3,data = soda6, na.action = na.omit)
m5 = lm(HP~ DOC+VLP*DM ,data = soda6, na.action = na.omit) #BEST - but there are a number of models that work similarity well;  But DM seems to be a bit more important than VLP 
m6 = lm(HP~ DOC+VLP+DM,data = soda6, na.action = na.omit) # Second best if I decide not to include interaction effects... Discuss with Mark... 
m7 = lm(HP~ DOC+DM,data = soda6, na.action = na.omit) 
BIC(m1,m2,m3,m4,m5,m6,m7)
summary(m1)
plot(m6)

# more extensive full model building approach:
source("function_model_selection.R")

soda.log<-soda; 
soda.log$HP<-log(soda$HP); soda.log$VLP<-log(soda$VLP) ; soda.log$DOC<-log(soda$DOC) ; soda.log$Grazer_small<-log(soda$Grazer_small);

interact<-data.frame(first = c("Lake","Lake","Grazer_small"), second = c("VLP","DOC","Lake"))
outcome<-model.sel(data = soda.log, dependant = c("HP"), predictors = c("VLP", "DM","DOC","Lake","Grazer_small"), interactions = interact)

# 2nd model seems best compromise between AIC and BIC based model selection
which(outcome$AICs== min(outcome$AICs))
mod.HP<-lm(data= soda.log, formula(outcome$grid.formula[2])) # accords with model m1 from above
mod.HP<-lm(data= soda5, formula(outcome$grid.formula[2]))

############################################################################################## E2_E3
m1 = lme(E2_E3~DOC, random = ~1| Lake, data = soda4, na.action = na.omit,method ="ML") #BEST - by far
m2 = lme(E2_E3~DOC, random = ~DOC| Lake, data = soda4, na.action = na.omit,method ="ML")
m3 = lm(E2_E3~DOC + Lake,  data = soda4, na.action = na.omit)
m4 = lm(E2_E3~DOC+DM,  data = soda4, na.action = na.omit)
AIC(m1,m2,m3,m4)
plot(m1)
# there are  residual issues with the linear model, which requires that we use a random effect structure instead to take care of the lake effect

############################################################################################## Chla

m1 = lm(Chla~VLP+Grazer_large+Grazer_small, data = soda6, na.action = na.omit)
m2 = lm(Chla~VLP+Grazer_large, data = soda6, na.action = na.omit)
m3 = lm(Chla~Grazer_large+Grazer_small, data = soda6, na.action = na.omit)
m4 = lm(Chla~Grazer_large, data = soda6, na.action = na.omit)
m5 = lm(Chla~VLP, data = soda6, na.action = na.omit)
m6 = lm(Chla~VLP+Grazer_large+DM, data = soda6, na.action = na.omit) # Best, but only marginally better than 10 - hence influence of VLP is questionable
m7 = lm(Chla~Grazer_large+DM, data = soda6, na.action = na.omit)
m8 = lm(Chla~Grazer_large+DM+Grazer_small, data = soda6, na.action = na.omit)
m9 = lme(Chla~ Grazer_large+DM+Grazer_small, data = soda6, na.action = na.omit, method ="ML", random = ~1| Lake)
m10 = lme(Chla~ Grazer_large+DM, data = soda6, na.action = na.omit, method ="ML", random = ~1| Lake)
m11 = lme(Chla~ Grazer_large+DM+VLP, data = soda6, na.action = na.omit, method ="ML", random = ~1| Lake)
m12 = lme(Chla~ Grazer_large+DM, data = soda6, na.action = na.omit, method ="ML", random = list(Lake = pdDiag(~DM)))
m13 = lme(Chla~ Grazer_large+DM, data = soda6, na.action = na.omit, method ="ML", random = list(Lake = pdDiag(~Grazer_large)))
m14 = lm(Chla~ Grazer_large+DM+VLP:Lake , data = soda6, na.action = na.omit)

AIC(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14)
summary(m14)
plot(m7)

############################################################################################## PM
m1 = lm(DM~Salinity, data = soda4, na.action = na.omit)
m2 = lme(DM~Salinity, data = soda4, na.action = na.omit, method ="ML",random = ~1| Lake)
m3 = lme(DM~Salinity, data = soda4, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity))) #Best - but will it converge???

AIC(m1,m2,m3)
summary(m3)
plot(m3)

# Alternative if lake is included as fixed effect - then a gls regression is required to account for the non-linearity in residuals.

mod0<-gls((DM)~(Salinity)+Lake:(Salinity)+Lake,data=soda6)
v<-varFixed(~(Salinity))
mod1<-gls((DM)~(Salinity)+Lake:(Salinity)+Lake,weights=v, method = "REML", data = soda6)
v<-varPower(form =~ (Salinity))
mod2<-gls((DM)~(Salinity)+Lake:(Salinity)+Lake,weights=v, method = "REML", data = soda6)
v<-varConstPower(form =~ (Salinity))
mod3<-gls((DM)~(Salinity)+Lake:(Salinity)+Lake,weights=v, method = "REML", data = soda6)
v<-varExp(form =~ (Salinity))
mod4<-gls((DM)~(Salinity)+Lake:(Salinity)+Lake,weights=v, method = "REML", data = soda6)
AIC(mod0,mod1,mod2,mod3,mod4) # exponential variance structure is again best
plot(mod3) # looks good!

mod.DM<-gls(log(DM)~(Salinity)+Lake:(Salinity)+Lake, weights=varConstPower(form =~ (Salinity)), method = "ML", data = soda6)
# the log model is much better - maybe we need to consider this here...

############################################################################################## DOC
m1 = lme(DOC~Salinity+DM+VLP, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))
m2 = lme(DOC~Salinity+DM+VLP+Grazer_large, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))
m3 = lme(DOC~Salinity+DM+VLP+Grazer_large+Chla, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))
m4 = lm(DOC~Salinity+DM+VLP, data = soda6, na.action = na.omit)
m5 = lm(DOC~Salinity+DM+VLP+Grazer_large, data = soda6, na.action = na.omit)
m6 = lm(DOC~Salinity+DM+VLP+Grazer_large+Grazer_small, data = soda6, na.action = na.omit)
m7 = lm(DOC~Salinity+DM+VLP+Grazer_large+Chla, data = soda6, na.action = na.omit)
m8 = lm(DOC~Salinity+DM+VLP+Grazer_small+Chla, data = soda6, na.action = na.omit)
m9 = lm(DOC~Salinity+DM+VLP+Grazer_large, data = soda6, na.action = na.omit)
m10 = lme(DOC~Salinity, data = soda6, na.action = na.omit, method ="ML",random = ~1| Lake)
m14 = lme(DOC~Salinity+VLP, data = soda6, na.action = na.omit, method ="ML",random = ~1| Lake)
m15 = lme(DOC~VLP, data = soda6, na.action = na.omit, method ="ML",random = ~1| Lake)
m11 = lme(DOC~Salinity, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))
m12 = lme(DOC~Salinity+VLP, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity))) #BEST
m13 = lme(DOC~Salinity+DM+VLP, data = soda6, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))

AIC(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15)
summary(m12)
plot(m12)


#### Step 3 - establish the piecewiseSEM #### 

AIC.SEM<-psem(DM = lme(DM~Salinity, data = soda4, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity))),
              Chla = lm(Chla~Grazer_large+DM+VLP, data = soda4, na.action = na.omit),
              E2_E3 = lme(E2_E3~DOC, random = ~1| Lake, data = soda4, na.action = na.omit,method ="ML"),
              HP = lm(HP~ DOC+VLP+DM,data = soda4, na.action = na.omit),
              VLP = lme(VLP~ DM, random = ~1| Lake, data = soda4, na.action = na.omit, method ="ML"),
              DOC = lme(DOC~Salinity+ VLP + DM, data = soda4, na.action = na.omit, method ="ML",random = ~1| Lake))
fisherC(AIC.SEM)
new.summary<-summary(AIC.SEM)
new.summary$dTable

# based on the piecewiseSEM diagnostics, we included also DM in the DOC model. The other significant suggestions, we did not conceptually
# meaningful and hence we decided against their inclusion.

# check coefficients
coefs(AIC.SEM)

########## Attain manually stanadrdised path coefficients and model r2
library(MuMIn)

# standardise data
soda5<-data.frame(soda4[,1],soda4$Lake,scale(soda4[,3:20], center = T, scale = T),soda4$dummy)
colnames(soda5)[2]<-c("Lake")
soda5$DM_log<-scale(log(soda4$DM))

# run the models
mod.DM<- lme(DM~Salinity, data = soda5, na.action = na.omit, method ="ML",random = list(Lake = pdDiag(~Salinity)))
summary(mod.DM)
r.squaredGLMM(mod.DM)

mod.Chla<- lm(Chla~Grazer_large+DM+VLP, data = soda5, na.action = na.omit)
summary(mod.Chla)

mod.E<- lme(E2_E3~DOC, random = ~1| Lake, data = soda5, na.action = na.omit,method ="ML")
summary(mod.E)
r.squaredGLMM(mod.E)

mod.HP = lm(HP~ DOC+VLP+DM,data = soda5, na.action = na.omit)
summary(mod.HP)

mod.VLP = lme(VLP~ DM, random = ~1| Lake, data = soda5, na.action = na.omit, method ="ML")
summary(mod.VLP)
r.squaredGLMM(mod.VLP)

mod.DOC = lme(DOC~Salinity+ VLP + DM, data = soda5, na.action = na.omit, method ="ML",random = ~1| Lake)
summary(mod.DOC)
r.squaredGLMM(mod.DOC)



########## step 4 - check whether the model estimations also hold true after running model2 regressoions ############
# A) Chla - grazer and vlp relationships
library(lmodel2)

soda2<-soda5[-which(is.na(soda5$Grazer_large) | is.na(soda5$DM) | is.na(soda5$VLP)), ]
mod.Chla<- lm(Chla~Grazer_large+DM+VLP, data = soda5, na.action = na.omit)
summary(mod.Chla)

soda2$residuals<-residuals(mod.Chla)
soda2$effect<-0.28723 * soda2$Grazer_large + soda2$residuals
Ex1.res <- lmodel2(soda2$effect ~ soda2$Grazer_large, nperm=99)

soda2$residuals<-residuals(mod.Chla)
soda2$effect<-0.05545 * soda2$VLP + soda2$residuals
Ex1.res <- lmodel2(soda2$effect ~ soda2$VLP, nperm=99)

# both of these tend to become larger - so the regression based approach should be more conservative 

soda2<-soda5[-which(is.na(soda5$DOC) | is.na(soda5$DM) | is.na(soda5$VLP)), ]
mod.HP = lm(HP~ DOC+VLP+DM,data = soda5, na.action = na.omit)
summary(mod.HP)

soda2$residuals<-residuals(mod.HP)
soda2$effect<-0.25881  * soda2$Grazer_large + soda2$residuals
Ex1.res <- lmodel2(soda2$effect ~ soda2$Grazer_large, nperm=99)

# same here - also becomes larger - so the regression based approach should be more conservative 
